==> zio-aws-groundstation_2.12-5.17.103.1-sources.jar: zio/aws/groundstation/model/GetMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import java.lang.Integer
import zio.aws.groundstation.model.primitives.{
  MissionProfileArn,
  ConfigArn,
  DurationInSeconds
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetMissionProfileResponse(
    contactPostPassDurationSeconds: Option[DurationInSeconds] = None,
    contactPrePassDurationSeconds: Option[DurationInSeconds] = None,
    dataflowEdges: Option[Iterable[Iterable[ConfigArn]]] = None,
    minimumViableContactDurationSeconds: Option[DurationInSeconds] = None,
    missionProfileArn: Option[MissionProfileArn] = None,
    missionProfileId: Option[String] = None,
    name: Option[String] = None,
    region: Option[String] = None,
    tags: Option[Map[String, String]] = None,
    trackingConfigArn: Option[ConfigArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse = {
    import GetMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
      .builder()
      .optionallyWith(
        contactPostPassDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.contactPostPassDurationSeconds)
      .optionallyWith(
        contactPrePassDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.contactPrePassDurationSeconds)
      .optionallyWith(
        dataflowEdges.map(value =>
          value.map { item =>
            item.map { item =>
              ConfigArn.unwrap(item): java.lang.String
            }.asJavaCollection
          }.asJavaCollection
        )
      )(_.dataflowEdges)
      .optionallyWith(
        minimumViableContactDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.minimumViableContactDurationSeconds)
      .optionallyWith(
        missionProfileArn.map(value =>
          MissionProfileArn.unwrap(value): java.lang.String
        )
      )(_.missionProfileArn)
      .optionallyWith(missionProfileId.map(value => value: java.lang.String))(
        _.missionProfileId
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(region.map(value => value: java.lang.String))(_.region)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(
        trackingConfigArn.map(value =>
          ConfigArn.unwrap(value): java.lang.String
        )
      )(_.trackingConfigArn)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.GetMissionProfileResponse.wrap(buildAwsValue())
}
object GetMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.GetMissionProfileResponse =
      zio.aws.groundstation.model.GetMissionProfileResponse(
        contactPostPassDurationSeconds.map(value => value),
        contactPrePassDurationSeconds.map(value => value),
        dataflowEdges.map(value => value),
        minimumViableContactDurationSeconds.map(value => value),
        missionProfileArn.map(value => value),
        missionProfileId.map(value => value),
        name.map(value => value),
        region.map(value => value),
        tags.map(value => value),
        trackingConfigArn.map(value => value)
      )
    def contactPostPassDurationSeconds: Option[DurationInSeconds]
    def contactPrePassDurationSeconds: Option[DurationInSeconds]
    def dataflowEdges: Option[List[List[ConfigArn]]]
    def minimumViableContactDurationSeconds: Option[DurationInSeconds]
    def missionProfileArn: Option[MissionProfileArn]
    def missionProfileId: Option[String]
    def name: Option[String]
    def region: Option[String]
    def tags: Option[Map[String, String]]
    def trackingConfigArn: Option[ConfigArn]
    def getContactPostPassDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "contactPostPassDurationSeconds",
      contactPostPassDurationSeconds
    )
    def getContactPrePassDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "contactPrePassDurationSeconds",
      contactPrePassDurationSeconds
    )
    def getDataflowEdges: ZIO[Any, AwsError, List[List[ConfigArn]]] =
      AwsError.unwrapOptionField("dataflowEdges", dataflowEdges)
    def getMinimumViableContactDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "minimumViableContactDurationSeconds",
      minimumViableContactDurationSeconds
    )
    def getMissionProfileArn: ZIO[Any, AwsError, MissionProfileArn] =
      AwsError.unwrapOptionField("missionProfileArn", missionProfileArn)
    def getMissionProfileId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("region", region)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getTrackingConfigArn: ZIO[Any, AwsError, ConfigArn] =
      AwsError.unwrapOptionField("trackingConfigArn", trackingConfigArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ) extends zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly {
    override val contactPostPassDurationSeconds: Option[DurationInSeconds] =
      scala
        .Option(impl.contactPostPassDurationSeconds())
        .map(value =>
          zio.aws.groundstation.model.primitives.DurationInSeconds(value)
        )
    override val contactPrePassDurationSeconds: Option[DurationInSeconds] =
      scala
        .Option(impl.contactPrePassDurationSeconds())
        .map(value =>
          zio.aws.groundstation.model.primitives.DurationInSeconds(value)
        )
    override val dataflowEdges: Option[List[List[ConfigArn]]] = scala
      .Option(impl.dataflowEdges())
      .map(value =>
        value.asScala.map { item =>
          item.asScala.map { item =>
            zio.aws.groundstation.model.primitives.ConfigArn(item)
          }.toList
        }.toList
      )
    override val minimumViableContactDurationSeconds
        : Option[DurationInSeconds] = scala
      .Option(impl.minimumViableContactDurationSeconds())
      .map(value =>
        zio.aws.groundstation.model.primitives.DurationInSeconds(value)
      )
    override val missionProfileArn: Option[MissionProfileArn] = scala
      .Option(impl.missionProfileArn())
      .map(value =>
        zio.aws.groundstation.model.primitives.MissionProfileArn(value)
      )
    override val missionProfileId: Option[String] =
      scala.Option(impl.missionProfileId()).map(value => value: String)
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val region: Option[String] =
      scala.Option(impl.region()).map(value => value: String)
    override val tags: Option[Map[String, String]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val trackingConfigArn: Option[ConfigArn] = scala
      .Option(impl.trackingConfigArn())
      .map(value => zio.aws.groundstation.model.primitives.ConfigArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ): zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-groundstation_2.12-5.17.166.1-sources.jar: zio/aws/groundstation/model/GetMissionProfileResponse.scala <==
package zio.aws.groundstation.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.groundstation.model.primitives.{
  MissionProfileArn,
  ConfigArn,
  DurationInSeconds
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetMissionProfileResponse(
    contactPostPassDurationSeconds: Optional[DurationInSeconds] =
      Optional.Absent,
    contactPrePassDurationSeconds: Optional[DurationInSeconds] =
      Optional.Absent,
    dataflowEdges: Optional[Iterable[Iterable[ConfigArn]]] = Optional.Absent,
    minimumViableContactDurationSeconds: Optional[DurationInSeconds] =
      Optional.Absent,
    missionProfileArn: Optional[MissionProfileArn] = Optional.Absent,
    missionProfileId: Optional[String] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    region: Optional[String] = Optional.Absent,
    tags: Optional[Map[String, String]] = Optional.Absent,
    trackingConfigArn: Optional[ConfigArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse = {
    import GetMissionProfileResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
      .builder()
      .optionallyWith(
        contactPostPassDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.contactPostPassDurationSeconds)
      .optionallyWith(
        contactPrePassDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.contactPrePassDurationSeconds)
      .optionallyWith(
        dataflowEdges.map(value =>
          value.map { item =>
            item.map { item =>
              ConfigArn.unwrap(item): java.lang.String
            }.asJavaCollection
          }.asJavaCollection
        )
      )(_.dataflowEdges)
      .optionallyWith(
        minimumViableContactDurationSeconds.map(value =>
          DurationInSeconds.unwrap(value): Integer
        )
      )(_.minimumViableContactDurationSeconds)
      .optionallyWith(
        missionProfileArn.map(value =>
          MissionProfileArn.unwrap(value): java.lang.String
        )
      )(_.missionProfileArn)
      .optionallyWith(missionProfileId.map(value => value: java.lang.String))(
        _.missionProfileId
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(region.map(value => value: java.lang.String))(_.region)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(
        trackingConfigArn.map(value =>
          ConfigArn.unwrap(value): java.lang.String
        )
      )(_.trackingConfigArn)
      .build()
  }
  def asReadOnly
      : zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly =
    zio.aws.groundstation.model.GetMissionProfileResponse.wrap(buildAwsValue())
}
object GetMissionProfileResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.GetMissionProfileResponse =
      zio.aws.groundstation.model.GetMissionProfileResponse(
        contactPostPassDurationSeconds.map(value => value),
        contactPrePassDurationSeconds.map(value => value),
        dataflowEdges.map(value => value),
        minimumViableContactDurationSeconds.map(value => value),
        missionProfileArn.map(value => value),
        missionProfileId.map(value => value),
        name.map(value => value),
        region.map(value => value),
        tags.map(value => value),
        trackingConfigArn.map(value => value)
      )
    def contactPostPassDurationSeconds: Optional[DurationInSeconds]
    def contactPrePassDurationSeconds: Optional[DurationInSeconds]
    def dataflowEdges: Optional[List[List[ConfigArn]]]
    def minimumViableContactDurationSeconds: Optional[DurationInSeconds]
    def missionProfileArn: Optional[MissionProfileArn]
    def missionProfileId: Optional[String]
    def name: Optional[String]
    def region: Optional[String]
    def tags: Optional[Map[String, String]]
    def trackingConfigArn: Optional[ConfigArn]
    def getContactPostPassDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "contactPostPassDurationSeconds",
      contactPostPassDurationSeconds
    )
    def getContactPrePassDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "contactPrePassDurationSeconds",
      contactPrePassDurationSeconds
    )
    def getDataflowEdges: ZIO[Any, AwsError, List[List[ConfigArn]]] =
      AwsError.unwrapOptionField("dataflowEdges", dataflowEdges)
    def getMinimumViableContactDurationSeconds
        : ZIO[Any, AwsError, DurationInSeconds] = AwsError.unwrapOptionField(
      "minimumViableContactDurationSeconds",
      minimumViableContactDurationSeconds
    )
    def getMissionProfileArn: ZIO[Any, AwsError, MissionProfileArn] =
      AwsError.unwrapOptionField("missionProfileArn", missionProfileArn)
    def getMissionProfileId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("missionProfileId", missionProfileId)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getRegion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("region", region)
    def getTags: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("tags", tags)
    def getTrackingConfigArn: ZIO[Any, AwsError, ConfigArn] =
      AwsError.unwrapOptionField("trackingConfigArn", trackingConfigArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ) extends zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly {
    override val contactPostPassDurationSeconds: Optional[DurationInSeconds] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contactPostPassDurationSeconds())
        .map(value =>
          zio.aws.groundstation.model.primitives.DurationInSeconds(value)
        )
    override val contactPrePassDurationSeconds: Optional[DurationInSeconds] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contactPrePassDurationSeconds())
        .map(value =>
          zio.aws.groundstation.model.primitives.DurationInSeconds(value)
        )
    override val dataflowEdges: Optional[List[List[ConfigArn]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataflowEdges())
        .map(value =>
          value.asScala.map { item =>
            item.asScala.map { item =>
              zio.aws.groundstation.model.primitives.ConfigArn(item)
            }.toList
          }.toList
        )
    override val minimumViableContactDurationSeconds
        : Optional[DurationInSeconds] = zio.aws.core.internal
      .optionalFromNullable(impl.minimumViableContactDurationSeconds())
      .map(value =>
        zio.aws.groundstation.model.primitives.DurationInSeconds(value)
      )
    override val missionProfileArn: Optional[MissionProfileArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.missionProfileArn())
        .map(value =>
          zio.aws.groundstation.model.primitives.MissionProfileArn(value)
        )
    override val missionProfileId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.missionProfileId())
      .map(value => value: String)
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val region: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.region())
      .map(value => value: String)
    override val tags: Optional[Map[String, String]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val trackingConfigArn: Optional[ConfigArn] = zio.aws.core.internal
      .optionalFromNullable(impl.trackingConfigArn())
      .map(value => zio.aws.groundstation.model.primitives.ConfigArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.GetMissionProfileResponse
  ): zio.aws.groundstation.model.GetMissionProfileResponse.ReadOnly =
    new Wrapper(impl)
}
